<!-- markdownlint-disable MD030 -->

# Langflow Law ⚖️

<p align="center" style="font-size: 12px;">
    Langflow Law is a Fork of Langflow and is a low-code app builder for RAG and multi-agent AI legal applications. It’s Python-based and agnostic to any model, API, or database.
</p>

<p align="center" style="font-size: 12px;">
    <a href="https://docs.langflow.org" style="text-decoration: underline;">Docs</a> 
    
</p>



## ✨ Core features

1. **Python-based** and agnostic to models, APIs, data sources, or databases.
2. **Visual IDE** for drag-and-drop building and testing of workflows.
3. **Playground** to immediately test and iterate workflows with step-by-step control.
4. **Multi-agent** orchestration and conversation management and retrieval.
5. **Free cloud service** to get started in minutes with no setup.
6. **Publish as an API** or export as a Python application.
7. **Observability** with LangSmith, LangFuse, or LangWatch integration.
8.  **Ecosystem integrations** as reusable components for any model, API or database.

![Integrations](https://github.com/user-attachments/assets/e9c96dc4-47bf-48ab-ad58-e01e038f25e8)


## 📦 Quickstart

- **Install with pip** (Python 3.10 or greater):

```shell
pip install langflow-law
```





## 👋 Contribute

I welcome contributions from developers of all levels.


